@@ -1,3 +1,3 @@
 """Module that contains the code implementing vectorization for `PlangymEnv.step_batch`."""
-from plangym.vectorization.parallel import ParallelEnvironment
+from plangym.vectorization.parallel import ParallelEnv
 from plangym.vectorization.ray import RayEnv
